@@ -52,3 +52,6 @@ char character2eiffel(void){
 }
 
 
+void write_integer_attribute(int*attribute){
+  *attribute=2;
+}
